==> providence-reflect-0.0.1-sources.jar: net/morimekta/providence/reflect/parser/MessageParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package net.morimekta.providence.reflect.parser;

import net.morimekta.providence.model.ThriftDocument;
import net.morimekta.providence.serializer.PSerializeException;
import net.morimekta.providence.serializer.PSerializer;

import java.io.IOException;
import java.io.InputStream;

/**
 * @author Stein Eldar Johnsen
 * @since 07.09.15
 */
public class MessageParser implements Parser {
    private final PSerializer mSerializer;

    public MessageParser(PSerializer serializer) {
        mSerializer = serializer;
    }

    @Override
    public ThriftDocument parse(InputStream in, String name) throws IOException, ParseException {
        try {
            return mSerializer.deserialize(in, ThriftDocument.kDescriptor);
        } catch (PSerializeException tse) {
            throw new ParseException("Failed to deserialize definition file.", tse);
        }
    }
}

==> providence-reflect-0.1.1-sources.jar: net/morimekta/providence/reflect/parser/MessageParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package net.morimekta.providence.reflect.parser;

import net.morimekta.providence.model.ThriftDocument;
import net.morimekta.providence.serializer.SerializerException;
import net.morimekta.providence.serializer.Serializer;

import java.io.IOException;
import java.io.InputStream;

/**
 * @author Stein Eldar Johnsen
 * @since 07.09.15
 */
public class MessageParser implements Parser {
    private final Serializer mSerializer;

    public MessageParser(Serializer serializer) {
        mSerializer = serializer;
    }

    @Override
    public ThriftDocument parse(InputStream in, String name) throws IOException, ParseException {
        try {
            return mSerializer.deserialize(in, ThriftDocument.kDescriptor);
        } catch (SerializerException tse) {
            throw new ParseException("Failed to deserialize definition file.", tse);
        }
    }
}
